!-------------------------------------------------------------------------------

!                      Code_Saturne version 5.0-alpha
!                      --------------------------
! This file is part of Code_Saturne, a general-purpose CFD tool.
!
! Copyright (C) 1998-2016 EDF S.A.
!
! This program is free software; you can redistribute it and/or modify it under
! the terms of the GNU General Public License as published by the Free Software
! Foundation; either version 2 of the License, or (at your option) any later
! version.
!
! This program is distributed in the hope that it will be useful, but WITHOUT
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
! details.
!
! You should have received a copy of the GNU General Public License along with
! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
! Street, Fifth Floor, Boston, MA 02110-1301, USA.

!-------------------------------------------------------------------------------

!===============================================================================
! Purpose:
! -------

!> \file cs_user_physical_properties-scalar-drift.f90
!> \brief Definition of physical variable laws for scalars with a drift.
!>
!-------------------------------------------------------------------------------

!-------------------------------------------------------------------------------
! Arguments
!______________________________________________________________________________.
!  mode           name          role                                           !
!______________________________________________________________________________!
!> \param[in]     nvar          total number of variables
!> \param[in]     nscal         total number of scalars
!> \param[in]     mbrom         indicator of filling of romb array
!> \param[in]     dt            time step (per cell)
!_______________________________________________________________________________

subroutine usphyv &
 ( nvar   , nscal  ,                                              &
   mbrom  ,                                                       &
   dt     )

!===============================================================================

!===============================================================================
! Module files
!===============================================================================

use paramx
use pointe
use numvar
use optcal
use cstphy
use cstnum
use entsor
use parall
use period
use field
use mesh
use field

!===============================================================================

implicit none

! Arguments

integer          nvar   , nscal,ivar

integer          mbrom, f_id

double precision dt(ncelet)

! Local variables

!< [loc_var_dec]
integer          iel, iscal, ifcvsl, nlelt, ilelt

double precision kr,ky,ktheta
double precision xyz(3)

double precision, dimension(:), pointer :: cvar_diff,  cvar_rho, cpro_cp
double precision, dimension(:,:), pointer ::  visten, cvar_k
double precision x, cp, lambda, rho_ref

integer, allocatable, dimension(:) :: lstelt

!< [loc_var_dec]
allocate(lstelt(ncel))
!===============================================================================

!===============================================================================
! 0. Initializations to keep
!===============================================================================

!< [init]
iscal = 1
! --- Stop if the cvar_diffsivity is not variable
!call field_get_key_int(ivarfl(isca(iscal)), kivisl, ifcvsl)
call field_get_key_int(ivarfl(isca(iscalt)), kivisl, ifcvsl)
if (ifcvsl.lt.0) then
   write(nfecra,1010) iscal
   call csexit (1)
endif

!Get the diffusivity/conductivity fiel
call field_get_val_s(ifcvsl, cvar_diff)

!Get the density field
call field_get_val_s(icrom, cvar_rho)

!Get the Cp fiel
call field_get_val_s(icp, cpro_cp)

!call getcel('Winding', nlelt, lstelt)

!Iron physical properties
cp =  2000  ! (J/(kg·K))
rho_ref = 1.2039 !Water density used as reference
lambda = 4  !  (W/(m·K))

call getcel('x<0.1 or x>0.9' , nlelt, lstelt)

do ilelt = 1, nlelt
   iel = lstelt(ilelt)
   cvar_rho(iel) = rho_ref
   cpro_cp(iel) = cp
   cvar_diff(iel) = lambda
enddo


!< [example_1]

!===============================================================================


!----
! End
!----

 1010 format(                                                     &
'@',/,                                                            &
'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
'@',/,                                                            &
'@ @@ WARNING:  stop when computing physical quantities',/,       &
'@    =======',/,                                                 &
'@    Inconsistent calculation data',/,                           &
'@',/,                                                            &
'@    For scalar', i10,/,                                         &
'@      the cvar_diffsivity is uniform while',/,                      &
'@      usphyv prescribes a variable diffusivity.',/,             &
'@',/,                                                            &
'@    The calculation will not be run.',/,                        &
'@',/,                                                            &
'@    Modify usipsu or usphyv.',/,                                &
'@                                                            ',/,&
'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
'@',/)

return
end subroutine usphyv
